@@ -38,8 +38,3 @@ def digital_nondigital_classifier(files):
     except FileExistsError as e:
         print("Error : {}".format(e.strerror))
         return "None", [], []
-
-classification, digital_pages, non_digital_pages = digital_nondigital_classifier("scansssmpl.pdf")
-print(classification)
-print(digital_pages)
-print(non_digital_pages)
